@@ -1,11 +1,11 @@
 use strict;
 use warnings;
 package String::Errf;
-BEGIN {
-  $String::Errf::VERSION = '0.005';
+{
+  $String::Errf::VERSION = '0.007';
 } # I really wanted to call it String::Fister.
 use String::Formatter 0.102081 ();
-use base 'String::Formatter';
+use parent 'String::Formatter';
 # ABSTRACT: a simple sprintf-like dialect
 
 use Scalar::Util ();
@@ -42,12 +42,12 @@ sub default_string_replacer { '__replace_errf' }
 sub default_hunk_formatter  { '__format_errf' }
 
 my $regex = qr/
- (%                   # leading '%'
-  (?:{                # {
-    (.*?)             #   mandatory argument name
-    (?: ; (.*?) )?    #   optional extras after semicolon
-  })                  # }
-  ([a-z])             # actual conversion character
+ (%                      # leading '%'
+  (?:{                   # {
+    ([^;]*?)             #   mandatory argument name
+    (?: ; ([^\}]*?) )?   #   optional extras after semicolon
+  })                     # }
+  ($|.)                  # potential conversion character
  )
 /xi;
 
@@ -185,9 +185,9 @@ sub _format_timestamp {
   my $type = $arg->{type} || 'datetime';
   my $zone = $arg->{tz}   || 'local';
 
-  my $format = $type eq 'datetime' ? '%Y-%m-%d %T'
+  my $format = $type eq 'datetime' ? '%Y-%m-%d %H:%M:%S'
              : $type eq 'date'     ? '%Y-%m-%d'
-             : $type eq 'time'     ? '%T'
+             : $type eq 'time'     ? '%H:%M:%S'
              : Carp::croak("unknown format type for %t: $type");
 
   # Supplying a time zone is *strictly informational*. -- rjbs, 2010-10-15
@@ -251,15 +251,18 @@ sub _format_numbered {
 1;
 
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 String::Errf - a simple sprintf-like dialect
 
 =head1 VERSION
 
-version 0.005
+version 0.007
 
 =head1 SYNOPSIS
 
@@ -277,7 +280,9 @@ version 0.005
 String::Errf provides C<errf>, a simple string formatter that works something
 like C<L<sprintf|perlfunc/sprintf>>.  It is implemented using
 L<String::Formatter> and L<Sub::Exporter>.  Their documentation may be useful
-in understanding or extending String::Errf.
+in understanding or extending String::Errf.  The C<errf> subroutine is only
+available when imported.  Calling L<String::Errf::errf> will not do what you
+want.
 
 =head1 DIFFERENCES FROM SPRINTF
 
@@ -422,10 +427,9 @@ Ricardo Signes <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Ricardo Signes.
+This software is copyright (c) 2013 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
